@@ -157,6 +157,7 @@ var (
 		"illumosamd64",
 		"iosarm64",
 		"jswasm",
+		"wasip1wasm",
 		"linux386",
 		"linuxamd64",
 		"linuxarm",
@@ -169,6 +170,7 @@ var (
 		"linuxmips64le",
 		"linuxs390x",
 		"linuxriscv64",
+		"linuxloong64",
 		"netbsd386",
 		"netbsdamd64",
 		"netbsdarm",
@@ -201,6 +203,7 @@ var (
 		"plan9",
 		"solaris",
 		"windows",
+		"wasip1",
 	}
 
 	validGoarch = []string{
@@ -217,6 +220,7 @@ var (
 		"s390x",
 		"wasm",
 		"riscv64",
+		"loong64",
 	}
 
 	validGoarm   = []string{"5", "6", "7"}
