@@ -12,7 +12,8 @@ import (
 	"time"
 
 	"github.com/caarlos0/log"
-	"github.com/google/go-github/v55/github"
+	"github.com/charmbracelet/x/exp/ordered"
+	"github.com/google/go-github/v56/github"
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
 	"github.com/goreleaser/goreleaser/pkg/config"
@@ -167,9 +168,9 @@ func (c *githubClient) CloseMilestone(ctx *context.Context, repo Repo, title str
 
 func headString(base, head Repo) string {
 	return strings.Join([]string{
-		firstNonEmpty(head.Owner, base.Owner),
-		firstNonEmpty(head.Name, base.Name),
-		firstNonEmpty(head.Branch, base.Branch),
+		ordered.First(head.Owner, base.Owner),
+		ordered.First(head.Name, base.Name),
+		ordered.First(head.Branch, base.Branch),
 	}, ":")
 }
 
@@ -196,8 +197,8 @@ func (c *githubClient) OpenPullRequest(
 	draft bool,
 ) error {
 	c.checkRateLimit(ctx)
-	base.Owner = firstNonEmpty(base.Owner, head.Owner)
-	base.Name = firstNonEmpty(base.Name, head.Name)
+	base.Owner = ordered.First(base.Owner, head.Owner)
+	base.Name = ordered.First(base.Name, head.Name)
 	if base.Branch == "" {
 		def, err := c.getDefaultBranch(ctx, base)
 		if err != nil {
@@ -281,7 +282,7 @@ func (c *githubClient) CreateFile(
 		Info("pushing")
 
 	if defBranch != branch && branch != "" {
-		_, res, err := c.client.Repositories.GetBranch(ctx, repo.Owner, repo.Name, branch, true)
+		_, res, err := c.client.Repositories.GetBranch(ctx, repo.Owner, repo.Name, branch, 100)
 		if err != nil && (res == nil || res.StatusCode != 404) {
 			return fmt.Errorf("could not get branch %q: %w", branch, err)
 		}
