@@ -6,11 +6,11 @@ import (
 	"path/filepath"
 	"testing"
 
-	"github.com/charmbracelet/keygen"
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/client"
 	"github.com/goreleaser/goreleaser/internal/git"
 	"github.com/goreleaser/goreleaser/internal/golden"
+	"github.com/goreleaser/goreleaser/internal/skips"
 	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/pkg/config"
@@ -245,7 +245,7 @@ func TestFullPipe(t *testing.T) {
 	} {
 		t.Run(name, func(t *testing.T) {
 			url := testlib.GitMakeBareRepository(t)
-			key := testlib.MakeNewSSHKey(t, keygen.Ed25519, "")
+			key := testlib.MakeNewSSHKey(t, "")
 
 			folder := t.TempDir()
 			ctx := testctx.NewWithCfg(
@@ -352,7 +352,7 @@ func TestFullPipe(t *testing.T) {
 
 func TestRunPipe(t *testing.T) {
 	url := testlib.GitMakeBareRepository(t)
-	key := testlib.MakeNewSSHKey(t, keygen.Ed25519, "")
+	key := testlib.MakeNewSSHKey(t, "")
 
 	folder := t.TempDir()
 	ctx := testctx.NewWithCfg(
@@ -488,7 +488,7 @@ func TestRunPipeNoBuilds(t *testing.T) {
 
 func TestRunPipeBinaryRelease(t *testing.T) {
 	url := testlib.GitMakeBareRepository(t)
-	key := testlib.MakeNewSSHKey(t, keygen.Ed25519, "")
+	key := testlib.MakeNewSSHKey(t, "")
 	folder := t.TempDir()
 	ctx := testctx.NewWithCfg(
 		config.Project{
@@ -699,7 +699,14 @@ func TestSkip(t *testing.T) {
 	t.Run("skip", func(t *testing.T) {
 		require.True(t, Pipe{}.Skip(testctx.New()))
 	})
-
+	t.Run("skip flag", func(t *testing.T) {
+		ctx := testctx.NewWithCfg(config.Project{
+			AURs: []config.AUR{
+				{},
+			},
+		}, testctx.Skip(skips.AUR))
+		require.True(t, Pipe{}.Skip(ctx))
+	})
 	t.Run("dont skip", func(t *testing.T) {
 		ctx := testctx.NewWithCfg(config.Project{
 			AURs: []config.AUR{
