@@ -269,7 +269,19 @@ func buildChangelog(ctx *context.Context) ([]string, error) {
 }
 
 func filterEntries(ctx *context.Context, entries []string) ([]string, error) {
-	for _, filter := range ctx.Config.Changelog.Filters.Exclude {
+	filters := ctx.Config.Changelog.Filters
+	if len(filters.Include) > 0 {
+		var newEntries []string
+		for _, filter := range filters.Include {
+			r, err := regexp.Compile(filter)
+			if err != nil {
+				return entries, err
+			}
+			newEntries = append(newEntries, keep(r, entries)...)
+		}
+		return newEntries, nil
+	}
+	for _, filter := range filters.Exclude {
 		r, err := regexp.Compile(filter)
 		if err != nil {
 			return entries, err
@@ -297,6 +309,15 @@ func sortEntries(ctx *context.Context, entries []string) []string {
 	return result
 }
 
+func keep(filter *regexp.Regexp, entries []string) (result []string) {
+	for _, entry := range entries {
+		if filter.MatchString(extractCommitInfo(entry)) {
+			result = append(result, entry)
+		}
+	}
+	return result
+}
+
 func remove(filter *regexp.Regexp, entries []string) (result []string) {
 	for _, entry := range entries {
 		if !filter.MatchString(extractCommitInfo(entry)) {
