@@ -12,6 +12,7 @@ import (
 	"time"
 
 	"github.com/goreleaser/goreleaser/internal/artifact"
+	"github.com/goreleaser/goreleaser/internal/skips"
 	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/pkg/config"
@@ -329,8 +330,24 @@ func TestRun(t *testing.T) {
 		require.Contains(t, err.Error(), "post hook failed")
 	})
 
+	t.Run("skipping post-hook", func(t *testing.T) {
+		ctx := ctx5
+		skips.Set(ctx, skips.PostBuildHooks)
+		ctx.Config.UniversalBinaries[0].Hooks.Post = []config.Hook{{Cmd: "exit 1"}}
+		require.NoError(t, Pipe{}.Run(ctx))
+	})
+
+	t.Run("skipping pre-hook", func(t *testing.T) {
+		ctx := ctx5
+		skips.Set(ctx, skips.PreBuildHooks)
+		ctx.Config.UniversalBinaries[0].Hooks.Pre = []config.Hook{{Cmd: "exit 1"}}
+		require.NoError(t, Pipe{}.Run(ctx))
+	})
+
 	t.Run("hook with env tmpl", func(t *testing.T) {
 		ctx := ctx5
+		ctx.Skips[string(skips.PostBuildHooks)] = false
+		ctx.Skips[string(skips.PreBuildHooks)] = false
 		ctx.Config.UniversalBinaries[0].Hooks.Pre = []config.Hook{{
 			Cmd: "echo {{.Env.FOO}}",
 			Env: []string{"FOO=foo-{{.Tag}}"},
@@ -341,6 +358,8 @@ func TestRun(t *testing.T) {
 
 	t.Run("hook with bad env tmpl", func(t *testing.T) {
 		ctx := ctx5
+		ctx.Skips[string(skips.PostBuildHooks)] = false
+		ctx.Skips[string(skips.PreBuildHooks)] = false
 		ctx.Config.UniversalBinaries[0].Hooks.Pre = []config.Hook{{
 			Cmd: "echo blah",
 			Env: []string{"FOO=foo-{{.Tag}"},
