@@ -11,11 +11,16 @@ import (
 	"strings"
 	"time"
 
+	"github.com/goreleaser/goreleaser/internal/logext"
 	"github.com/goreleaser/goreleaser/internal/yaml"
 	"github.com/goreleaser/nfpm/v2/files"
 	"github.com/invopop/jsonschema"
 )
 
+type Versioned struct {
+	Version int
+}
+
 // Git configs.
 type Git struct {
 	TagSort          string   `yaml:"tag_sort,omitempty" json:"tag_sort,omitempty" jsonschema:"enum=-version:refname,enum=-version:creatordate,default=-version:refname"`
@@ -1034,7 +1039,7 @@ type Docker struct {
 	Files              []string `yaml:"extra_files,omitempty" json:"extra_files,omitempty"`
 	BuildFlagTemplates []string `yaml:"build_flag_templates,omitempty" json:"build_flag_templates,omitempty"`
 	PushFlags          []string `yaml:"push_flags,omitempty" json:"push_flags,omitempty"`
-	Use                string   `yaml:"use,omitempty" json:"use,omitempty"`
+	Use                string   `yaml:"use,omitempty" json:"use,omitempty" jsonschema:"enum=docker,enum=buildx,default=docker"`
 }
 
 // DockerManifest config.
@@ -1144,6 +1149,7 @@ type Source struct {
 
 // Project includes all project configuration.
 type Project struct {
+	Version         int              `yaml:"version,omitempty" json:"version,omitempty" jsonschema:"enum=1,default=1"`
 	ProjectName     string           `yaml:"project_name,omitempty" json:"project_name,omitempty"`
 	Env             []string         `yaml:"env,omitempty" json:"env,omitempty"`
 	Release         Release          `yaml:"release,omitempty" json:"release,omitempty"`
@@ -1339,12 +1345,31 @@ func Load(file string) (config Project, err error) {
 	return LoadReader(f)
 }
 
+type VersionError struct {
+	current int
+}
+
+func (e VersionError) Error() string {
+	return fmt.Sprintf(
+		"only configurations files on %s are supported, yours is %s, please update your configuration",
+		logext.Keyword("version: 1"),
+		logext.Keyword(fmt.Sprintf("version: %d", e.current)),
+	)
+}
+
 // LoadReader config via io.Reader.
 func LoadReader(fd io.Reader) (config Project, err error) {
 	data, err := io.ReadAll(fd)
 	if err != nil {
 		return config, err
 	}
+
+	var versioned Versioned
+	_ = yaml.Unmarshal(data, &versioned)
+	if versioned.Version != 0 && versioned.Version != 1 {
+		return config, VersionError{versioned.Version}
+	}
+
 	err = yaml.UnmarshalStrict(data, &config)
 	return config, err
 }
